﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Infragistics.Windows.DataPresenter;

namespace HostAnyControl
{
    public partial class PointEditControl : UserControl
    {
        XamDataGrid _grid;

        public static readonly DependencyProperty ViewModelProperty =
            DependencyProperty.Register("ViewModel", typeof (RowViewModel), typeof (PointEditControl), new PropertyMetadata(default(RowViewModel), new PropertyChangedCallback(ViewModelChanged)));

        private static void ViewModelChanged(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            PointEditControl control = dependencyObject as PointEditControl;
            if (control != null)
            {
                RowViewModel vm = e.NewValue as RowViewModel;
                if (vm != null)
                    control.DataContext = new Point(vm.Point1.X, vm.Point1.Y);
            }
        }

        public RowViewModel ViewModel
        {
            get { return (RowViewModel) GetValue(ViewModelProperty); }
            set { SetValue(ViewModelProperty, value); }
        }

        public PointEditControl()
        {
            InitializeComponent();
        }

        public PointEditControl(XamDataGrid grid)
            : this()
        {
            _grid = grid;
        }

        public void EnterEditMode()
        {
            //this.textBox.Focus();
            this.xValue.Focus();
        }

        protected override void OnPreviewKeyDown(KeyEventArgs e)
        {
            if (_grid != null && e.Key == Key.Tab && base.IsKeyboardFocusWithin)
            {
                e.Handled = true;

                bool activeCellEditMode = e.KeyboardDevice.Modifiers == ModifierKeys.Shift;
                SwitchFocusToNextCell(activeCellEditMode);
            }

            base.OnPreviewKeyDown(e);
        }

        private void SwitchFocusToNextCell(bool activeCellEditMode)
        {
            RoutedCommand cmd =
                activeCellEditMode
                    ? // If the Shift key is pressed, put the active cell into edit mode.
                    DataPresenterCommands.StartEditMode
                    : DataPresenterCommands.CellNextByTab;

            _grid.ExecuteCommand(cmd);
        }

        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            RowViewModel vm = ViewModel;
            vm.Point1 = new Point((double)xValue.Value, (double)yValue.Value);
            SwitchFocusToNextCell(false);
        }
    }
}